@@ -9,7 +9,7 @@ class CustomActionService(RPCService):
 
     def __init__(self, rabbit_url, device_key, actions):
         self.actions = actions
-        self.allowed_actions = filter(not_hidden_method, dir(self.actions))
+        self._allowed_actions = filter(not_hidden_method, dir(self.actions))
         super(CustomActionService, self).__init__(
             rabbit_url=rabbit_url,
             queue_name='custom_action_service',
@@ -17,16 +17,13 @@ class CustomActionService(RPCService):
             request_action=self._perform_custom_action)
 
     def _perform_custom_action(self, instruction):
-        result = {'error': 1, 'action': instruction['action'], 'response': "An error occurred"}
-
-        if instruction['action'] not in self.allowed_actions:
-            result['response'] = "'action' must be one of: {0}".format(', '.join(self.allowed_actions))
-            return result
+        try:
+            if instruction['action'] not in self._allowed_actions:
+                return self._error("'action' must be one of: {0}".format(', '.join(self._allowed_actions)))
+        except KeyError:
+            return self._error("'action' must be defined")
 
         try:
-            result['response'] = getattr(self.actions, instruction['action'])()
-            result['error'] = 0
+            return self._response(getattr(self.actions, instruction['action'])())
         except Exception as e:
-            result['response'] = e.message
-
-        return result
+            return self._error(e.message)
